version 6.0
log	using 96figures.log, replace
# delimit;

*	Date:		June 10, 2002
*	Author:	Catherine Wilson
*	Purpose:	Gnerate figures for context paper;

set memory 30000;
set more off;
set obs 1;

set obs 601;
generate a=_n;
replace a=a+99;
replace a=(a/100);
summarize a;

generate self=3;
generate dem=3.5;
generate rep=a;

generate udem=-((self-dem)*(self-dem));
generate urep=-((self-rep)*(self-rep));
generate contextd=((urep)/(udem+urep))-(1/2);
generate contextr=((udem)/(udem+urep))-(1/2);
replace udem=(udem/31.73518);
replace urep=(urep/31.73518);

generate rep1=4.5;
generate urep1=-((self-rep1)*(self-rep1));
generate contexd0=.4;
generate contexr0=-.4;
replace urep1=(urep1/31.73518);

generate news12=1;
generate news36=0;
generate news7=0;
generate age=.41304347;
generate secqrt=1;
generate thrdqrt=0;
generate frthqrt=0;
generate hs=0;
generate somecoll=0;
generate ba=0;
generate grad=0;
summarize;


* Coefficients for Uncorrected  Estimation;


generate consd=-1.3584;
generate d1=1.4912;
generate d2=0.4104;
generate d3=0.3535;
generate d4=0.6094;
generate d5=0.5288;
generate d6=0.7391;
generate d7=0.2631;
generate d8=0.2181;
generate d9=0.0747;
generate d10=1.5908;
generate d11=0.2556;
generate d12=0.3282;
generate d13=0.4582;
generate consr=-2.3535;
generate r1=1.4912;
generate r2=0.4104;
generate r3=0.9063;
generate r4=1.0010;
generate r5=1.3794;
generate r6=1.2117;
generate r7=0.3071;
generate r8=0.7666;
generate r9=0.8735;
generate r10=2.0341;
generate r11=0.3159;
generate r12=0.4481;
generate r13=0.3010;


* Generate the correlation;

generate sigma=0.2381;
generate cor1=((1-sigma)/((2*(1-sigma))^(1/2)));

* Generate predicted probabilities of Outcomes;

generate based1=consd+((d1)*udem)+((d2)*contextd)+((d3)*hs)+((d4)*somecoll)
	+((d5)*ba)+((d6)*grad)+((d7)*secqrt)+((d8)*thrdqrt)+((d9)*frthqrt)+
	((d10)*age)+((d11)*news12)+((d12)*news36)+((d13)*news7);
generate based2=consr+((r1)*urep)+((r2)*contextr)+((r3)*hs)+((r4)*somecoll)+
	((r5)*ba)+((r6)*grad)+((r7)*secqrt)+((r8)*thrdqrt)+((r9)*frthqrt)+
	((r10)*age)+((r11)*news12)+((r12)*news36)+((r13)*news7);
generate based21=consr+((r1)*urep1)+((r2)*contextr)+((r3)*hs)+((r4)*somecoll)+
	((r5)*ba)+((r6)*grad)+((r7)*secqrt)+((r8)*thrdqrt)+((r9)*frthqrt)+
	((r10)*age)+((r11)*news12)+((r12)*news36)+((r13)*news7);
generate based10=consd+((d1)*udem)+((d2)*contexd0)+((d3)*hs)+((d4)*somecoll)
	+((d5)*ba)+((d6)*grad)+((d7)*secqrt)+((d8)*thrdqrt)+((d9)*frthqrt)+
	((d10)*age)+((d11)*news12)+((d12)*news36)+((d13)*news7);
generate based20=consr+((r1)*urep)+((r2)*contexr0)+((r3)*hs)+((r4)*somecoll)+
	((r5)*ba)+((r6)*grad)+((r7)*secqrt)+((r8)*thrdqrt)+((r9)*frthqrt)+
	((r10)*age)+((r11)*news12)+((r12)*news36)+((r13)*news7);

* Probability of voting Democratic;

generate pd=(binorm(based1, (based1-based2), cor1));

* Probability of Voting Republican;

generate pr=(binorm(based2, (based2-based1), cor1));

* Calculate probability of abstention;

generate pa=(1-pd-pr);
generate pt=(1-pa);

* Probability of voting Democratic holding distance;

generate pd1=(binorm(based1, (based1-based21), cor1));

* Probability of Voting Republican holding distance;

generate pr1=(binorm(based21, (based21-based1), cor1));

* Calculate probability of abstention holding distance;

generate pa1=(1-pd1-pr1);
generate pt1=(1-pa1);

* Probability of voting Democratic holding context;

generate pd0=(binorm(based10, (based10-based20), cor1));

* Probability of Voting Republican holding context;

generate pr0=(binorm(based20, (based20-based10), cor1));

* Calculate probability of abstention holding context;

generate pa0=(1-pd0-pr0);
generate pt0=(1-pa0);


drop if rep<4.00;

label	var	contextd 	"Context-Dependent Measure";
label	define	conlab	30 "4" 49 "7";
label	values	contextd	 conlab;

label var	pa	"Abstention, total effect";
label var	pa1	"Abstention, context effect";
label var	pd	"Vote Democrat, total effect";
label var	pd1	"Vote Democrat, context effect";
graph pa pa1 pd pd1 rep, s(iiii) c(mm[#_#]m[..]m[..#_#]) 
	sort ylab(.44, .48, .52) xlab(4, 5, 6, 7) bands(25)
	b2("Republican Candidate Ideological Location")
	l1("Probability of Vote Decision")
	saving(context);
translate context.gph context.ps;
translate context.gph context.eps;


label var	pa0	"Abstention, isolation effect";
label var	pd0	"Vote Democrat, isolation effect";
graph pa pa0 pd pd0 rep, s(iiii) c(mm[#_#]m[..]m[..#_#]) 
	sort ylab(.44, .48, .52) xlab(4, 5, 6, 7) bands(25)
	b2("Republican Candidate Ideological Location")
	l1("Probability of Vote Decision")
	saving(context4);
translate context4.gph context4.ps;
translate context4.gph context4.eps;

log close;
exit;
