version 6.0
log	using data961.log, replace
# delimit;

*	Date:		May 9, 2002
*	Author:	Catherine Wilson
*	Purpose:	First set of steps to create dataset to study context dependence

set memory 30000;
set more off;

* Reading Variables;
* Note that the data source used in the following command is the 1996 National 
	Election Studies data collection made publicly available by the University 
	of Michigan;

infix	incumb 196-197 stdis 220-223 news 447 self 689 selfcat 692
	close 706 pid 743 strngpid 744 
	educat 943-944 faminc 1087-1088 age 940-941 vote 1562 housevot 1577
	choice 1580 vdem94 3097-3102 vrep94 3103-3108 vtot94 3109-3114
	using /home/chw/NESdata/1996/NES1996.DAT;


* tabulate all variables;

tabulate incumb;
summarize stdis;
tabulate news;
tabulate self;
tabulate selfcat;
tabulate close;
tabulate news;
tabulate pid;
tabulate strngpid;
tabulate educat;
tabulate faminc;
tabulate age;
tabulate vote;
tabulate housevot;
tabulate choice;
summarize vdem94;
summarize vrep94;
summarize vtot94;


* Recodes - Missing Data;


recode self 8=.; 
recode self 9=.;
recode self 0=.;
recode selfcat 7=.;
recode selfcat 8=.;
recode selfcat 9=.;
recode selfcat 0=.;
recode stdis 0=.;
recode vote 6=.;
recode vote 7=.;
recode vote 8=.;
recode vote 9=.;
recode vote 0=.;
recode vote 5=0;
recode choice 7=.;
recode choice 8=.;
recode choice 9=.;
recode choice 0=.;
recode close 8=.;
recode close 9=.;
recode close 0=.;
recode close 2=0;
recode news 8=.;
recode news 9=.;
recode pid 4=.;
recode pid 5=.;
recode pid 8=.;
recode pid 9=.;
recode strngpid 8=.;
recode strngpid 9=.;
recode strngpid 0=.;
recode strngpid 5=0;
recode educat 98=.;
recode educat 99=.;
recode age 99=.;
recode faminc 88=.;
recode faminc 98=.;
recode faminc 99=.;
recode housevot 8=.;
recode housevot 9=.;
recode housevot 0=.;
recode housevot 5=0;
recode vdem94 -9=.;
recode vrep94 -9=.;
recode vtot94 -9=.;

* Create label descriptions;

label	var	self 			"own position on 7 pt scale";
label	define	selflab	1 "ext lib" 2 "very lib" 3 "slt lib" 4 "moderate" 
	5 "slt cons" 6 "very cons" 7 "ext cons";
label	values	self selflab;

label	var	selfcat 		"self ideology categorization";
label	define	selclab	1 "lib" 3 "moderate" 5 "cons";
label	values	selfcat selclab;

label	var	incumb	 		"house incumbent type";
label	define	inclab	12 "democrat/challenger" 14 "democrat/unopposed" 
	21 "republican/challenger" 24 "republican/unopposed" 55 "no democrat" 
	65 "no republican" 00 "Washington DC";
label	values	incumb inclab;

label	var	vote 		"voted in election";
label	define	votlab	0 "no" 1 "yes";
label	values	vote votlab;

label	var	choice		"choice in election";
label	define	chlab		1 "Democrat" 2 "Republican" 3 "other";
label	values	choice chlab;

label	var	news 		"reads a daily newspaper";
label	values	news newslab;

label	var	pid 		"party identification";
label	define	pidlab	1 "democrat" 2 "republican" 3 "independent";
label	values	pid pidlab;

label	var	strngpid 	"strength of pid";
label	define	spidlab	1 "strong" 0 "not very strong";
label	values	strngpid spidlab;

label	var	educat 	"years of education of respondent";
label	values	educat	 edulab;

label	var	age 		"respondent age";
label	values	age agelab;

label	var	faminc	"respondent's family income";
label values	faminc	famlab;

label	var	close 	"respondent's perception that race is close";
label	define	clslab	1 "close" 0 "not close" ;
label	values	close	 clslab;

label	var	housevot 	"respondent voted in house election";
label	define	houslab		1 "yes" 0 "no" ;
label	values	housevot	 houslab;

label	var	vdem94		"votes for dem house cand in 94";
label	var	vrep94		"votes for rep house cand in 94";
label	var	vtot94		"total votes for house cands in 94";

* tabulate all variables;

tabulate incumb;
summarize stdis;
tabulate news;
tabulate self;
tabulate selfcat;
tabulate close;
tabulate news;
tabulate pid;
tabulate strngpid;
tabulate educat;
tabulate faminc;
tabulate age;
tabulate vote;
tabulate housevot;
tabulate choice;
summarize vdem94;
summarize vrep94;
summarize vtot94;


* create a year variable;

generate year=1996;

label	var	year	 	"year of survey";
label	values	year yearlab;

tabulate year;

save 	data961, replace;
log close;
exit;

