version 6.0
log	using data962.log, replace
# delimit;

*	Date:		May 9, 2002
*	Author:	Catherine Wilson
*	Purpose:	Second set of steps to create dataset to study context dependence

set memory 30000;
set more off;

* Reading Variables;
* Note that the data source used in the following command is the Project Vote
	Smart NPAT data in the form generously made available to us by its creators Stephen 	Ansolabehere, James Snyder, and Charles Stewart. This data is described in: 	Ansolabehere, S., Snyder, J. and Stewart, C. 2001a "Party Positioning in U.S. 
	House Elections." AJPS 45:136-159. and 
	Ansolabehere, S., Snyder, J. and Stewart, C. 2001b "The Effects of Party and 
	Preferences in Congressional Roll-Call Voting." Legislative Studies Quarterly 
	26:533-572.;

use npat.dta;

* tabulate all variables;

summarize;

* Fix up dataset;

generate st=.;
replace st=1 if state=="CT";
replace st=2 if state=="ME";
replace st=3 if state=="MA";
replace st=4 if state=="NH";
replace st=5 if state=="RI";
replace st=6 if state=="VT";
replace st=11 if state=="DE";
replace st=12 if state=="NJ";
replace st=13 if state=="NY";
replace st=14 if state=="PA";
replace st=21 if state=="IL";
replace st=22 if state=="IN";
replace st=23 if state=="MI";
replace st=24 if state=="OH";
replace st=25 if state=="WI";
replace st=31 if state=="IA";
replace st=32 if state=="KS";
replace st=33 if state=="MN";
replace st=34 if state=="MO";
replace st=35 if state=="NE";
replace st=36 if state=="ND";
replace st=37 if state=="SD";
replace st=40 if state=="VA";
replace st=41 if state=="AL";
replace st=42 if state=="AR";
replace st=43 if state=="FL";
replace st=44 if state=="GA";
replace st=45 if state=="LA";
replace st=46 if state=="MS";
replace st=47 if state=="NC";
replace st=48 if state=="SC";
replace st=49 if state=="TX";
replace st=51 if state=="KY";
replace st=52 if state=="MD";
replace st=53 if state=="OK";
replace st=54 if state=="TN";
replace st=55 if state=="DC";
replace st=56 if state=="WV";
replace st=61 if state=="AZ";
replace st=62 if state=="CO";
replace st=63 if state=="ID";
replace st=64 if state=="MT";
replace st=65 if state=="NV";
replace st=66 if state=="NM";
replace st=67 if state=="UT";
replace st=68 if state=="WY";
replace st=71 if state=="CA";
replace st=72 if state=="OR";
replace st=73 if state=="WA";
replace st=81 if state=="AK";
replace st=82 if state=="HI";

replace st=(st*100);
generate stdis=st+dist;
summarize stdis;
sort stdis;

save 96npat, replace;
drop if party==1;
rename x_imputed rep;
rename name repname;
drop x party state dist;
save 96npat1, replace;
clear;
use 96npat.dta;
drop if party==2;
rename x_imputed dem;
rename name demname;
drop x party state dist;
save 96npat2, replace;
clear;

use data961.dta;
summarize;
sort stdis;
merge stdis using 96npat1.dta;
tabulate _merge;
rename _merge _merge1;
save data962.dta, replace;
sort stdis;
merge stdis using 96npat2.dta;
tabulate _merge;
rename _merge _merge2;

* Generate variables for final model;

generate action=.;
replace action=0 if vote==0;
replace action=0 if housevot==0;
replace action=1 if choice==1;
replace action=2 if choice==2;

generate dem1=((dem*6)+1);
generate rep1=((rep*6)+1);
summarize dem1 rep1;
generate udem=-((self-dem1)*(self-dem1));
generate urep=-((self-rep1)*(self-rep1));
generate contextd=((urep)/(udem+urep))-(1/2);
generate contextr=((udem)/(udem+urep))-(1/2);

summarize udem urep contextd contextr;
list udem if udem==0;
list urep if urep==0;

generate hs=1 if educat==12;
generate somecoll=1 if educat>12 & educat<16;
generate ba=1 if educat==16;
generate grad=1 if educat==17;
replace hs=0 if hs==.;
replace somecoll=0 if somecoll==.;
replace ba=0 if ba==.;
replace grad=0 if grad==.;

generate secqrt=1 if faminc>11 & faminc<17;
generate thrdqrt=1 if faminc>16 & faminc<21;
generate frthqrt=1 if faminc>20 & faminc<25;
replace secqrt=0 if secqrt==.;
replace thrdqrt=0 if thrdqrt==.;
replace frthqrt=0 if frthqrt==.;

generate news12=1 if news>0 & news<3;
generate news36=1 if news>2 & news<7;
generate news7=1 if news==7;
replace news12=0 if news12==.;
replace news36=0 if news36==.;
replace news7=0 if news7==.;

drop if action==.;
drop if udem==.;
drop if urep==.;
drop if educat==.;
drop if faminc==.;
drop if age==.;
drop if news==.;

* Adjust scale of variables for estimation;

replace udem=(udem/31.73518);
replace urep=(urep/31.73518);
replace age=(age/92);

outfile action udem urep contextd contextr hs somecoll ba grad secqrt thrdqrt 
	frthqrt age news12 news36 news7 using data962, 
	nolabel replace;

save 	data962, replace;
log close;
exit;

